
<iframe 
style="
width: __$data.widthIframe$__px;
height: __$data.heightIframe$__px;
border: 0px gray solid;
"
sandbox="allow-scripts allow-pointer-lock allow-modals" 
scrolling="no"
marginheight="0"
marginwidth="0" 
srcdoc="{-% include 'main.tpl.html' %-}">
</iframe>
